package internalFrame2;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.beans.PropertyVetoException;

import javax.swing.JButton;
import javax.swing.JDesktopPane;
import javax.swing.JFrame;
import javax.swing.JInternalFrame;
import javax.swing.JTree;
import javax.swing.UIManager;
import javax.swing.event.InternalFrameAdapter;
import javax.swing.event.InternalFrameEvent;

import com.japisoft.xmlpad.XMLContainer;
import com.japisoft.xmlpad.look.LookManager;

/**
 * <p>Here a demo for using an unique tree shared by several XML containers.
 * Note that the developer has to manage a focus and unfocus state for
 * synchronizing the tree with the right view.</p>
 * @author (c) 2004 JAPISoft / http://www.japisoft.com
 * @version 1.0
 * */
public class DemoInternalFrame2 extends JInternalFrame {

    private XMLContainer container;

    public DemoInternalFrame2( JTree sharedTree, boolean focus ) {
	super();
	container = new XMLContainer();
	// This is the initial focus
	if ( focus )
	    container.focus();
	else
	    container.unfocus();
	// This is the common tree
	container.setTreeDelegate( sharedTree );
	getContentPane().add( container.getView() );
	// Here a listener for detecting that our container looses the focus
	addInternalFrameListener( new CustomInternalFrameAdapter() );
    }

    // It is important to have only one container having the focus at a time
    class CustomInternalFrameAdapter extends InternalFrameAdapter {

	public void internalFrameClosed( InternalFrameEvent e ) {
	    // We dispose the container
	    container.dispose();
	}

	public void internalFrameActivated( InternalFrameEvent e) {
	    // We unfocus the previous focus container
	    JDesktopPane dp = getDesktopPane();
	    JInternalFrame[] frame = dp.getAllFrames();
	    for ( int i = 0; i < frame.length; i++ ) {
		if ( frame[ i ] instanceof DemoInternalFrame2 ) {
		    if ( ( ( DemoInternalFrame2 )frame[ i ] ).container.hasFocus() ) {
			( ( DemoInternalFrame2 )frame[ i ] ).container.unfocus();
			break;
		    }
		}
	    }
			
	    // Notify the container that he has the focus
	    container.focus();
	}
    }

    public static void main( String[] args ) {

	try {
	    UIManager.setLookAndFeel( UIManager.getSystemLookAndFeelClassName() );
	} catch( Exception exc ) {
	}

	JFrame fr = new JFrame();
	final JDesktopPane dp = new JDesktopPane();
	fr.getContentPane().add( dp );
		
	JInternalFrame treeFrame = new JInternalFrame( "Tree" );
	// We build here the tree shared by several XMLContainer
	final JTree sharedTree = new JTree();
	// We update the "look-and-feel" of the tree
	LookManager.install( null, sharedTree );
		
	treeFrame.getContentPane().add( sharedTree );
	dp.add( treeFrame );
	treeFrame.setBounds( 10, 10, 100, 300 );
	treeFrame.setResizable( true );
	treeFrame.setVisible( true );

	// Editor 1

	DemoInternalFrame2 innerFrame1 = new DemoInternalFrame2( sharedTree, true );
	dp.add( innerFrame1 );
	innerFrame1.setBounds( 150, 10, 200, 300 );
	innerFrame1.setResizable( true );
	innerFrame1.setClosable( true );
	innerFrame1.setVisible( true );

	// Editor 2
		
	DemoInternalFrame2 innerFrame2 = new DemoInternalFrame2( sharedTree, false );
	dp.add( innerFrame2 );
	innerFrame2.setBounds( 410, 50, 250, 300 );
	innerFrame2.setResizable( true );
	innerFrame2.setClosable( true );
	innerFrame2.setVisible( true );

		
	JButton button = new JButton( "Add a new editor" );
	button.addActionListener(
				 new ActionListener() {
				     public void actionPerformed( ActionEvent e ) {

					 DemoInternalFrame2 innerFrame = new DemoInternalFrame2( sharedTree, false );
					 dp.add( innerFrame );
					 innerFrame.setBounds( (int)( Math.random() * 200 ), (int)( Math.random() * 200 ), 250, 300 );
					 innerFrame.setResizable( true );
					 innerFrame.setClosable( true );
					 innerFrame.setVisible( true );
												
						
				     }
				 } );

	// Frame for adding a new editor
	JInternalFrame frame = new JInternalFrame( "Add" );
	frame.getContentPane().add( button );
	frame.pack();
	frame.setLocation( 100, 400 );
	frame.setVisible( true );
	dp.add( frame );

	fr.setSize( 700, 500 );
	fr.setVisible( true );
				
    }
	
}
